@@ -16,8 +16,10 @@
 #   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 
+import copy
 from . import defs
 from . import utils
+from . import scanner
 import re
 
 #   macros \newcommand, \renewcommand
@@ -112,6 +114,28 @@ def h_hspace(parser, buf, mac, args, delim, pos):
         return []
     return [defs.SpaceToken(pos, ' ')]
 
+
+def h_linebreak(parser, buf, mac, args, delim, pos):
+    r"""
+    Handler for macro `\linebreak` taking one optional argument.
+
+    Adds no additional space for optional argument '0','1','2','3'.
+    Adds one SpaceToken for argument '4', or no argument.
+    Adds Latexerror for other arguments, we allow additional whitespace.
+    """
+    if len(args[0]) == 0:
+        return [defs.SpaceToken(pos, ' ')]
+    else:
+        arg = parser.get_text_expanded(args[0]).strip()
+        if arg == '4':
+            return [defs.SpaceToken(pos, ' ')]
+        elif arg in ['0','1','2','3']:
+            # There is no line break for arguments 0,1,2,3
+            return []
+    # For all other arguments, return an error
+    return utils.latex_error(parser, r'`\linebreak` only takes values 0,1,2,3 or 4', pos)
+
+
 #   macro \cite[opt]
 #
 def h_cite(parser, buf, mac, args, delim, pos):
@@ -161,3 +185,22 @@ def h_load_module(prefix):
         return utils.filter_set_toks(out, pos, None)
     return f
 
+
+# \MakeLowercase
+def h_makeLowercase(parser, buf, mac, args, delim, pos):
+    toks = parser.expand_sequence(scanner.Buffer(args[0].copy()))
+    def f(t):
+        if type(t) is defs.TextToken:
+            t.txt = t.txt.lower()
+        return t
+    return [f(t) for t in toks]
+
+
+# \MakeUppercase
+def h_makeUppercase(parser, buf, mac, args, delim, pos):
+    toks = parser.expand_sequence(scanner.Buffer(args[0].copy()))
+    def f(t):
+        if type(t) is defs.TextToken:
+            t.txt = t.txt.upper()
+        return t
+    return [f(t) for t in toks]
