@@ -5,7 +5,7 @@
 
 from yalafi.defs import Environ, InitModule
 
-require_packages = []
+require_packages = ['graphicx']
 
 def init_module(parser, options, position):
     parms = parser.parms
